@@ -117,7 +117,7 @@ class EncryptablePeer:
     id: tuple
     reader: asyncio.StreamReader
     writer: asyncio.StreamWriter
-    key_data: KeyData = KeyData()
+    key_data: KeyData = field(default_factory=KeyData)
     encrypted: bool = False
     authenticated: bool = False
     separator = b"<?!!?>"
@@ -646,6 +646,11 @@ class EncryptedSocketServerTransport(ServerTransport):
         msg = RpcReplyMessage(data)
         peer = self.peers.get_peer(context)
 
+        if not peer:
+            # socket has been terminated / removed
+            log.warning(f"Peer {context} has been destroyed... dropping reply")
+            return
+
         log.debug(
             f"Decoded RPC response (before encryption): {bson.decode(msg.payload)}"
         )
